@@ -13,9 +13,11 @@ depends: cherrypy, pywebsite, feedparser
 """
 
 # pip install cherrypy pywebsite feedparser
-import os, smtplib, re, time, hashlib, csv, pprint
+import os, smtplib, re, time, hashlib, csv, pprint, subprocess
 import xml.sax.saxutils
 from email.mime.text import MIMEText
+from email.Utils import formatdate
+
 
 import cherrypy
 import feedparser
@@ -33,7 +35,7 @@ except ValueError:
 
 
 def sendmail(fromaddr, toaddrs, subject, body, 
-            smtp_host, smtp_username, smtp_password):
+            smtp_host, smtp_username, smtp_password, use_sendmail_cmd):
     """ sendmail(fromaddr, toaddrs, subject, body, 
                  smtp_host, smtp_username, smtp_password) sends an email.
     """
@@ -44,13 +46,43 @@ def sendmail(fromaddr, toaddrs, subject, body,
     msg['Subject'] = subject
     msg['From'] = fromaddr
     msg['To'] = toaddrs
+    msg["Date"] = formatdate(localtime=True)
+
+
+    if use_sendmail_cmd:
+        # try to use the local sendmail cmd to send the mail.
+        email_message = msg.as_string()
+        print email_message
+        _local_sendmail_cmd(email_message)
+
+    else:
+
+        server = smtplib.SMTP(smtp_host)
+        server.ehlo()
+        # if we are using the SSL port then we try and use tls.
+        if smtp_host.endswith(":587"):
+            server.starttls()
+        if smtp_username:
+            server.login(smtp_username, smtp_password)
+        server.sendmail(fromaddr, toaddrs, msg.as_string())
+        server.quit()
+
+
+
+def _local_sendmail_cmd(email_message):
+    """ _local_sendmail_cmd uses the unix sendmail command to send the email.
+    """
+    sendmail_location = "/usr/sbin/sendmail"
+    pipe = subprocess.Popen([sendmail_location, "-t"], stdin=subprocess.PIPE)
+    pipe.communicate(email_message)
+
+    retcode = pipe.wait()
+    if retcode is not None and retcode >> 8:
+        raise RuntimeError("email failed to send :%s:" % retcode)
+
+
+
 
-    server = smtplib.SMTP(smtp_host)
-    server.starttls()  
-    if smtp_username:
-        server.login(smtp_username, smtp_password)
-    server.sendmail(fromaddr, toaddrs, msg.as_string())  
-    server.quit()  
 
 def __utf8(value):
     if isinstance(value, unicode):
@@ -247,7 +279,9 @@ class MyNewsletterSend(NewsletterSend):
                 toaddr, subject, body, 
                 self.config.get('smtp_host'), 
                 self.config.get('smtp_username'), 
-                self.config.get('smtp_password'))
+                self.config.get('smtp_password'),
+                self.config.get('sendmail_cmd'),
+                )
         return True
 
     def make_send_parts_db(self):
@@ -301,7 +335,9 @@ class MyNewsletter(Newsletter):
                 toaddr, subject, body, 
                 self.config.get('smtp_host'), 
                 self.config.get('smtp_username'), 
-                self.config.get('smtp_password'))
+                self.config.get('smtp_password'),
+                self.config.get('sendmail_cmd'),
+                )
 
     def send_unsubscribe_confirm_email(self, uid, user):
         """ send_unsubscribe_confirm_email(uid, user) sends an 
@@ -321,7 +357,9 @@ class MyNewsletter(Newsletter):
                 toaddr, subject, body, 
                 self.config.get('smtp_host'), 
                 self.config.get('smtp_username'), 
-                self.config.get('smtp_password'))
+                self.config.get('smtp_password'),
+                self.config.get('sendmail_cmd'),
+                )
 
     def make_subscribers_db(self):
         """ make_subscribers_db() returns a key value store to be used as
@@ -522,6 +560,8 @@ class WebNewsletterAdmin(object):
 
         if subscribe_automatically == "yes":
             subscribe_automatically = True
+        else:
+            subscribe_automatically = False
 
         if csv_text is None:
             # show input fields
@@ -537,7 +577,7 @@ class WebNewsletterAdmin(object):
                 # we set it as subscribed automatically.
                 self._n.subscribe(d['email'], 
                                   info = info, 
-                                  subscribed = True)
+                                  subscribed = subscribe_automatically)
             return self.html_template("import_success")
 
     def create(self, newsletter_send_id, subject, body):
@@ -854,8 +894,9 @@ if __name__ == "__main__":
         log_dir = os.path.join("log")
         #if not os.path.exists(log_dir):
         #    os.mkdir(log_dir)
-        cherrypy.config.update({'environment': 'production',
-                                'log.error_file': os.path.join(log_dir, 'error.log'),
+        #cherrypy.config.update({'environment': 'production'})
+
+        cherrypy.config.update({'log.error_file': os.path.join(log_dir, 'error.log'),
                                 #...
                                 })
 
